#
# spec file for package libraw1394
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libraw1394
Version:        2.1.0
Release:        7.5
Summary:        A Firewire Interface
License:        LGPL-2.1+
Group:          System/Kernel
Url:            http://www.dennedy.org/libraw1394/
# bug437293
%ifarch ppc64
Obsoletes:      libraw1394-64bit
%endif
#
BuildRequires:  openjade-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        http://www.kernel.org/pub/linux/libs/ieee1394/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
Patch:          libraw1394.no-isodump.patch

%description
The Linux kernel's IEEE 1394 subsystem provides access to the raw 1394
bus through the raw1394 module.  This includes the standard 1394
transactions (read, write, lock) on the active side, isochronous
stream receiving and sending and dumps of data written to the
FCP_COMMAND and FCP_RESPONSE registers.  raw1394 uses a character
device to communicate to user programs using a special protocol.

libraw1394 was created with the intent to hide that protocol from
applications so that

- the protocol has to be implemented correctly only once.

- all work can be done using easy to understand functions instead of
  handling a complicated command structure.

- only libraw1394 has to be changed when raw1394's interface changes.

Maintainer: Dan Dennedy <dan@dennedy.org>

Original author: Andreas Bombe <andreas.bombe@munich.netsurf.de>
                 or <bombe@informatik.tu-muenchen.de>

Contributors:
Manfred Weihs <weihs@ict.tuwien.ac.at>
Christian Toegel <christian.toegel@gmx.at>
Dan Maas <dmaas@maasdigital.com>
Ben Collins <bcollins@debian.org>
Pieter Palmers <pieterp@joow.be>

%package 11
Summary:        A Firewire Interface
Group:          System/Kernel
# bug437293
%ifarch ppc64
Obsoletes:      libraw1394-64bit
%endif
#

%description 11
A library for the Linux IEEE-1394 subsystem, which provides direct
access to the connected 1394 (Firewire) bus.

%package devel
Summary:        Development and Include Files for libraw1394
Group:          Development/Libraries/C and C++
Summary(pt_BR): Arquivos de desenvolvimento e cabeçalhos para o libraw1394
Requires:       %{name}-11 == %{version}
Requires:       glibc-devel
# bug437293
%ifarch ppc64
Obsoletes:      libraw1394-devel-64bit
%endif
#

%description devel
Libraw1394 is the only supported interface to the kernel side raw1394
of the Linux IEEE-1394 subsystem, which provides the user space direct
access to the connected 1394 buses.  Through libraw1394/raw1394,
applications can directly send to and receive from other nodes without
requiring a kernel driver for the protocol in question.

This archive contains the header files for libraw1394 development.

%prep
%setup -q
%patch -p1

%build
#autoreconf --force --install
export CFLAGS="%optflags"
%configure --disable-static --with-pic
%{__make} %{?jobs:-j%jobs} all

%install
%{__make} install DESTDIR=%{buildroot}
# empty dependency libs
rm -f %{buildroot}%{_libdir}/libraw1394.la

%clean
rm -rf $RPM_BUILD_ROOT

%post 11 -p /sbin/ldconfig

%postun 11 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING* NEWS README
%{_bindir}/testlibraw
%{_bindir}/dumpiso
%{_bindir}/sendiso
%{_mandir}/man*/*

%files 11
%defattr(-,root,root)
%{_libdir}/libraw1394.so.11*

%files devel
%defattr(-,root,root)
%{_includedir}/libraw1394
%{_libdir}/libraw1394.so
%{_libdir}/pkgconfig/libraw1394.pc

%changelog
* Sat Mar 23 2013 zaitor@opensuse.org
- Update to version 2.1.0:
  + Behavior changes of the backend to firewire-core:
  - The isochronous reception buffer is now mapped read/writable
    rather than read-only.
  - Decrease memory footprint of IR and IT buffers by avoiding
    some internal rounding up of the buffer size.
  + New APIs in <libraw1394/raw1394.h>:
  - raw1394_add_config_rom_descriptor(): Add contents to
    the Configuration ROM of the local node(s). At runtime, this
    API is only available if running on top of firewire-core.
  - raw1394_remove_config_rom_descriptor(): Counterpart to
    raw1394_add_config_rom_descriptor().
  - raw1394_read_cycle_timer_and_clock(): Like the existing
    raw1394_read_cycle_timer(), but lets the caller choose
    between CLOCK_REALTIME, CLOCK_MONOTONIC, or
    CLOCK_MONOTONIC_RAW.
  - raw1394_get_speed(): Returns the speed code of the maximum
    possible transmission speed between a given node and the
    local node.
  - enum raw1394_iso_speed was extended by RAW1394_ISO_SPEED_800,
    _1600, and _3200.
  + New APIs in <libraw1394/ieee1394.h>: Added preprocessor
    constants L1394_SPEED_BETA, L1394_SPEED_800, _1600, and _3200.
  + testlibraw1394: Added unit tests of the new APIs.
- Changes from version 2.0.9:
  + Fix that raw1394_iso_recv_flush() did not have any effect when
    running on firewire-core alias juju kernel drivers.
    This fix needs kernel 3.4 or later at runtime.
  + Remove build-time dependency on linux-headers.
  + Remove --with-fw-dir configure switch which is no longer useful
  + Janitorial fixes.
- Changes from version 2.0.8:
  + Performance improvement: Configuration ROM access via
    raw1394_read() is dramatically faster and very robust now.
  + Interoperability fix: Internally retry
    raw1394_read/write/lock/lock64() after ack-busy response.
  + Small bug fixes.
* Tue Jul 26 2011 aj@suse.de
- Update to version 2.0.7:
  * Fixes playback to some audio devices based on the DICE chipset.
  * Several fixes for using libraw1394 on top of the firewire-core
    kernel driver (as opposed to raw1394 which was removed in kernel
    2.6.37).
* Sat Oct 16 2010 jslaby@suse.de
- convert Summary(pt_BR) to UTF-8
* Thu Sep 30 2010 davejplater@gmail.com
- Update to version 2.0.5
- See https://ieee1394.wiki.kernel.org/index.php/Release_Notes_-_Libraries
  for changes since 1.3.0
- Upstream urls changed as http://www.linux1394.org/ is up for sale
  and no longer in use.
- Removed patch libraw1394.eventloop-return.patch, already integrated.
- Removed mpg1394grab.patch and mpg1394grab-beautify.patch as the upstream
  maintainer says that streaming video support is now integrated.
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to provide the correct symbols
* Fri Dec 18 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Jun 25 2008 olh@suse.de
- eventloop.c: fix to retry read when failed with EINTR.
* Wed May 21 2008 cthiel@suse.de
- fix baselibs.conf
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Mar 18 2008 crrodriguez@suse.de
- remove pointless libtool archive with empty dependency_libs
- remove static libraries
- update to version 1.3.0
  * added raw1394_read_cycle_timer() as used by FFADO project.
  * added support for environment variable RAW1394DEV to override default device node /dev/raw1394.
  * added --with-valgrind to configure script. other optimizations and bugfixes - see ChangeLog.
* Sat Aug  4 2007 olh@suse.de
- remove isodump.5 man page
  split libraw1394-8 package which contains only libraries
* Mon Jan 29 2007 olh@suse.de
- add mpg1394grab (#236537)
* Tue Jul 18 2006 olh@suse.de
- update to version 1.2.1
  generate compiler warnings on deprecated functions (legacy isochronous).
  bugfixes and optimizations.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jul  1 2005 olh@suse.de
- update to version 1.2.0
  add bugfix stalling on iso transmission underflow
* Tue Jan 11 2005 olh@suse.de
- update to version 1.1.0
* Mon Mar  8 2004 lmuelle@suse.de
- update to version 0.10.1
* Fri Feb 20 2004 kkaempf@suse.de
- adapt aclocal definitions to automake 1.8.x (#34793)
* Sun Jan 11 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Jan 27 2003 kukuk@suse.de
- Move .so symlinks into -devel package [Bug #22382]
* Sun Jan 12 2003 aj@suse.de
- Fix multiline strings.
* Wed Jun 19 2002 ro@suse.de
- run autoreconf
* Thu Jun  6 2002 bk@suse.de
- fix defattr properly(for perms of includedir, mandir, docdir)
- never ever include %%{_mandir}/* (dirs!) into package filelist
- fix rpm license tag to LGPL and add URL tag und use optflags
* Tue May 28 2002 lmuelle@suse.de
- fixed directory permissions of includedir
* Tue Feb 26 2002 kraxel@suse.de
- added automake m4 file to devel package file list
- fixed s390x build failure
* Fri Sep 21 2001 bjacke@suse.de
- initial build: version 0.9.0
